==> viha-5.15.tar.gz: viha-5.15/ryhma-takt-1.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma";
$file = basename(__FILE__);

include "common.php";
include "ryhma-ok.php";
include "tap-ok.php";
include "hlo-ok.php";

echo "
<html>
<head>
 <title>VIHA - Ryhm</title>
</head>
" . body_bgcolor() . "
<h2>" . ota_paivystys_nimi() . ", ryhmkohtaisten tietojen pivitys</h2>
";

taktiset_linkit();

function paikat ($current_ryhma_id, $current_paikka_id)
{
  global $prefix;
  
  $sql1 =
    "SELECT id,paikka
     FROM paikka
     WHERE id != $current_paikka_id
           AND (paivystys_id = " . s("paivystys") . "
                OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
                OR alue_id = 2)
     ORDER BY paikka";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_ryhma_id&paikka_id=$b[id]\">", 
      "$b[paikka]</a>\n";
  }
}

function ryhma_tilat ($current_ryhma_id, $current_ryhma_tila_id)
{
  global $prefix;

  $sql1 =
    "SELECT id,ryhma_tila
      FROM ryhma_tila
      WHERE id != $current_ryhma_tila_id
            AND (paivystys_id = " . s("paivystys") . "
                 OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
                 OR alue_id = 2)
      ORDER BY ryhma_tila";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_ryhma_id&ryhma_tila_id=$b[id]\">",
      "$b[ryhma_tila]</a>\n";
  }
}

$id = get_nro('id');
$ryhma_tila_id = get_nro('ryhma_tila_id');
$paikka_id = get_nro('paikka_id');
$koordinaatit = get_txt('koordinaatit');
$tap = get_txt('tap');
$tehtava = get_txt('tehtava');
$toiminta_alue = get_txt('toiminta_alue');
$toimintakanava = get_txt('toimintakanava');

$save = get_txt('save');
$combo = get_txt('combo');

oltava_sallittu($file, $table, $id);

# major magic - combo operations
if ($combo != '') {
  $to_ryhma_tila = 0; $to_hlo_tila = 0; $to_ryhma = 0;
  switch ($combo) {
  case "":
    break;
  case "VAPAANA":
    $to_ryhma_tila = 2; $to_hlo_tila = 3;
    $to_selite = " vapaaksi ja siihen kuuluvat henkilt paikalle";
    break;
  case "KIINTEA":
    $to_ryhma_tila = 9; $to_hlo_tila = 3;
    $to_selite = " kiinteksi ja siihen kuuluvat henkilt paikalle";
    break;
  case "TAUOLLA":
    $to_ryhma_tila = 8; $to_hlo_tila = 4;
    $to_selite = " ja kaikki siihen kuuluvat henkilt tauolle";
    break;
  case "ALOITTAA":
    $to_ryhma_tila = 11; $to_hlo_tila = 2;
    $to_selite =
      " aloittavaksi ja kaikki siihen kuuluvat henkilt tulossa oleviksi";
    break;
  case "LOPETTANUT":
    $to_ryhma_tila = 12; $to_hlo_tila = 5;
    $to_selite =
      " lopettaneeksi ja kaikki siihen kuuluvat henkilt poistuneiksi";
    break;
  case "KIERRATYS":
    $to_ryhma_tila = 12; $to_hlo_tila = 3; $to_ryhma = 1;
    $to_selite =
      " lopettaneeksi ja kaikki siihen kuuluvat henkilt vapaiksi";
    break;
  default:
    die("$file: tuntamaton combo $combo");
  }
  if (saa_tehda("$file:combo")) {
    $ret1 = ryhma_set_ryhma_tila_id_ok($herja1,$id,$to_ryhma_tila);
    $ret2 = hlo_set_hlo_tila_id_by_ryhma_id_ok($herja2,$id,$to_hlo_tila);
    if (($ret1 != 2) && ($ret2 != 2)) {
      $now = date('Y-m-d H:i:s');
      $sql =
	"UPDATE $table
         SET ryhma_tila_id=$to_ryhma_tila,
             ts='$now'
         WHERE id=$id";
      $result = my_mysql_query ($sql,true,true);
      $where = "WHERE ryhma_id=$id";
      $sql =
	"UPDATE hlo SET hlo_tila_id=$to_hlo_tila, ts='$now' $where";
      $result = my_mysql_query ($sql,true,true);
      add_hlo_ajat_sql($where);
      echo "<p>Yhdistelmpivitys $combo tehty.\n";
      if ($to_ryhma != 0) {
	$sql =
	  "UPDATE hlo
           SET ryhma_id = $to_ryhma, ts = '$now'
           WHERE ryhma_id = $id";
	my_mysql_query($sql,true,true);
	add_hlo_ajat_sql("WHERE ryhma_id = $to_ryhma");
      }
      taktinen_loki(ota_kutsu($id) . $to_selite);
    }
    p_herja($ret1,$herja);
    p_herja($ret2,$herja);
  }
 }

if (($ryhma_tila_id != '') && saa_tehda("$file:ryhma_tila_id")) {
  $ret = ryhma_set_ryhma_tila_id_ok($herja,$id,$ryhma_tila_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table SET ryhma_tila_id=$ryhma_tila_id, ts='$now' WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
    taktinen_loki(ota_kutsu($id)
		  . " "
		  . ota_ryhma_tila($ryhma_tila_id));
  }
  p_herja($ret,$herja);
}

if (($paikka_id != '') && saa_tehda("$file:paikka_id")) {
  $ret = ryhma_set_paikka_id_ok($herja,$id,$paikka_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "UPDATE $table SET paikka_id=$paikka_id, ts='$now' WHERE id=$id";
    $result = my_mysql_query ($sql);
    echo "<p>Tiedot pivitetty.\n";
    loki($sql);
    taktinen_loki(ota_kutsu($id)
		  . ", sijainti on nyt "
		  . ota_paikka($paikka_id));
  }
  p_herja($ret,$herja);
}

if (($save != '') && saa_tehda("$file:save")) {
  $ret = ryhma_set_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    # jos koordinaatit ovat jo ennestn samat, ei lokia. samoin muut.
    $kdup = tab_col_id($table,"koordinaatit",$id);
    $tdup = tab_col_id($table,"tehtava",$id);
    $adup = tab_col_id($table,"toiminta_alue",$id);
    $kdup = tab_col_id($table,"toimintakanava",$id);
    $sql =
      "UPDATE $table
       SET koordinaatit='$koordinaatit',
           tehtava = '$tehtava',
           toiminta_alue = '$toiminta_alue',
           toimintakanava = '$toimintakanava',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    loki($sql);
    if ($kdup != $koordinaatit) {
      echo "<p>Koordinaatit asetettu: $koordinaatit\n";
      taktinen_loki(ota_kutsu($id)
		    . ": koordinaatit ovat nyt $koordinaatit");
    } # kdup
    if ($tdup != $tehtava) {
      echo "<p>Tehtv asetettu: $tehtava\n";
      taktinen_loki(ota_kutsu($id)
		    . ": tehtv: $tehtava");
    } # tdup
    if ($adup != $toiminta_alue) {
      echo "<p>Toiminta-alue asetettu: $toiminta_alue\n";
      taktinen_loki(ota_kutsu($id)
		    . ": toiminta-alue: $toiminta_alue");
    } # adup
    if ($kdup != $toimintakanava) {
      echo "<p>Toimintakanava asetettu: $toimintakanava\n";
      taktinen_loki(ota_kutsu($id)
		    . ": toimintakanava: $toimintakanava");
    } # kdup
  }
  p_herja($ret,$herja);
  if ($tap != '') {
    $ret = tap_add_ok($herja,s('alue'),
		      s('paivystys'),$id,$tap);
    $clear = "SAVE";
    if ($ret != 2) {
      $now = date('Y-m-d H:i:s');
      $sql =
	"INSERT INTO tap
         SET alue_id = " . s("alue") . ",
             paivystys_id = " . s("paivystys") . ",
             ryhma_id = $id,
             tap = '$tap',
             ts = '$now'";
      $result = my_mysql_query ($sql);
      loki("$sql id=" . last_insert_id());
      taktinen_loki(ota_kutsu($id)
		    . ": $tap");
      echo "<p>Kirjaus tehty: $tap\n";
    }
    p_herja($ret,$herja);
  }
}

echo "<form action=\"\" method=\"GET\">\n";

echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

$sql =
  "SELECT kutsu,ryhma_tila_id,paikka_id,ryhma_tila,paikka,koordinaatit,verkko,
          $table.tehtava,$table.toiminta_alue,$table.toimintakanava
   FROM $table,ryhma_tila,paikka,verkko
   WHERE ryhma.id = $id
         AND ryhma_tila.id = ryhma_tila_id
         AND paikka.id = paikka_id
         AND verkko.id = verkko_id";
$result = my_mysql_query($sql);
$a = mysql_fetch_array($result);
$kutsu = $a['kutsu'];
$ryhma_tila_id = $a['ryhma_tila_id'];
$paikka_id = $a['paikka_id'];
$ryhma_tila = $a['ryhma_tila'];
$paikka = $a['paikka'];
$koordinaatit = $a['koordinaatit'];
$verkko = $a['verkko'];
$tehtava = $a['tehtava'];
$toiminta_alue = $a['toiminta_alue'];
$toimintakanava = $a['toimintakanava'];

echo "<table border=0>\n";
echo "<tr><td>Oletusverkko:<td>" . ota_oletus_verkko() . "\n";
echo "<tr><td>Kutsu:<td>$kutsu" . muotoile_verkko($verkko, $id) . "\n";
echo tr_bgcolor() . "<th><th>Nykyinen<th>Pivitysvaihtoehdot";
echo "<tr><td>Tila:<td" . bgcolor_vaalsin() . ">$ryhma_tila<td>";
ryhma_tilat ($id, $ryhma_tila_id);
echo "<tr><td>Sijainti:<td" . bgcolor_vaalsin() . ">$paikka<td>";
paikat ($id, $paikka_id);

echo "<tr><td><td>Koordinaatit";
echo "<td><input type=\"text\" name=\"koordinaatit\" size=32 maxlength=32\n";
echo " value=\"$koordinaatit\">\n";

echo "<tr><td><td>Tehtv";
echo "<td><input type=\"text\" name=\"tehtava\" size=64 maxlength=128\n";
echo " value=\"$tehtava\">\n";

echo "<tr><td><td>Toiminta-alue";
echo "<td><input type=\"text\" name=\"toiminta_alue\" size=64 maxlength=128\n";
echo " value=\"$toiminta_alue\">\n";

echo "<tr><td><td>Toimintakanava";
echo "<td><input type=\"text\" name=\"toimintakanava\" size=32 maxlength=32\n";
echo " value=\"$toimintakanava\">\n";

echo "<tr><td><td>Kirjaus";
echo "<td><input type=\"text\" name=\"tap\" size=64 maxlength=255\n";
echo " value=\"\">\n";

echo "<tr><td><td><input type=\"submit\" name=\"save\" value=\"TALLETA\">\n";

echo "</table>\n";

echo "<h2>Pivitysyhdistelmt (combot)</h2>";

echo "<table>
<tr><th>Yhdistelm<th>Selitys
<tr>
  <td><a href=\"$file?combo=VAPAANA&id=$id\">
    <font color=green>Vapaaksi<font></a>
  <td>Merkitse tm ryhm vapaaksi ja kaikki siihen kuuluvat henkilt paikalle.
<tr>
  <td><a href=\"$file?combo=KIINTEA&id=$id\">
    <font color=green>Kiinteksi<font></a>
  <td>Merkitse tm ryhm kiinteksi ja kaikki siihen kuuluvat henkilt
    paikalle.
<tr>
  <td><a href=\"$file?combo=TAUOLLA&id=$id\"><font color=blue>Tauolle<font></a>
  <td>Merkitse tm ryhm ja kaikki siihen kuuluvat henkilt tauolle.
<tr>
  <td><a href=\"$file?combo=ALOITTAA&id=$id\">
    <font color=blue>Aloittavaksi<font></a>
  <td>Merkitse tm ryhm aloittavaksi ja kaikki siihen kuuluvat henkilt
    tulossa oleviksi.
<tr>
  <td><a href=\"$file?combo=LOPETTANUT&id=$id\">
    <font color=blue>Lopettaneeksi<font></a>
  <td>Merkitse tm ryhm lopettaneeksi ja kaikki siihen kuuluvat henkilt
    poistuneiksi.
<tr>
  <td><a href=\"$file?combo=KIERRATYS&id=$id\">
    <font color=blue>Kierrtetyksi<font></a>
  <td>Merkitse tm ryhm lopettaneeksi ja vapauta sen henkilkunta odottamaan
    sijoittamista uuteen ryhmn.
</table>";

echo "<h2>Tulosteet</h2>";

echo "<p><a href=\"toimintaryhman-kortti.php?id=$id\">",
  "Toimintaryhmn kortti</a>\n";

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma-takt-1.php,v 1.35 2009/05/08 09:43:09 riku Exp $ -->

==> viha-5.27.tar.gz: viha-5.27/ryhma-takt-1.php <==
<?php

# Copyright (C) 2009 Riku Kalinen
# License conditions in the file lisenssi.html
# Lisenssiehdot tiedostossa lisenssi.html

$table = "ryhma";
$file = basename(__FILE__);

include "common.php";
include "ryhma-ok.php";
include "tap-ok.php";
include "hlo-ok.php";

echo "
<html>
<head>
 <title>VIHA - Ryhm</title>
</head>
" . body_bgcolor() . "
<h2>" . muotoile_operaatio() . ", ryhmkohtaisten tietojen pivitys</h2>
";

taktiset_linkit();

function paikat ($current_ryhma_id, $current_paikka_id)
{
  global $prefix;
  
  $sql1 =
    "SELECT id,paikka
     FROM paikka
     WHERE id != $current_paikka_id
           AND (paivystys_id = " . s("paivystys") . "
                OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
                OR alue_id = 2)
     ORDER BY paikka";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_ryhma_id&paikka_id=$b[id]\">", 
      "$b[paikka]</a>\n";
  }
}

function ryhma_tilat ($current_ryhma_id, $current_ryhma_tila_id)
{
  global $prefix;

  $sql1 =
    "SELECT id,ryhma_tila
      FROM ryhma_tila
      WHERE id != $current_ryhma_tila_id
            AND (paivystys_id = " . s("paivystys") . "
                 OR (alue_id = " . s("alue") . " AND paivystys_id = 2)
                 OR alue_id = 2)
      ORDER BY ryhma_tila";
  $result1 = my_mysql_query ($sql1);
  while ($b = mysql_fetch_array($result1)) {
    echo "<a href=\"$file?id=$current_ryhma_id&ryhma_tila_id=$b[id]\">",
      "$b[ryhma_tila]</a>\n";
  }
}

$id = get_nro('id');
$ryhma_tila_id = get_nro('ryhma_tila_id');
$paikka_id = get_nro('paikka_id');
$koordinaatit = get_txt('koordinaatit');
$tap = get_txt('tap');
$tehtava = get_txt('tehtava');
$toiminta_alue = get_txt('toiminta_alue');
$toimintakanava = get_txt('toimintakanava');

$save = get_txt('save');
$combo = get_txt('combo');

oltava_sallittu($file, $table, $id);

# major magic - combo operations
if ($combo != '') {
  $to_ryhma_tila = 0; $to_hlo_tila = 0; $to_ryhma = 0;
  switch ($combo) {
  case "":
    break;
  case "VAPAANA":
    $to_ryhma_tila = 2; $to_hlo_tila = 3;
    $to_selite = " vapaaksi ja siihen kuuluvat henkilt paikalle";
    break;
  case "KIINTEA":
    $to_ryhma_tila = 9; $to_hlo_tila = 3;
    $to_selite = " kiinteksi ja siihen kuuluvat henkilt paikalle";
    break;
  case "TAUOLLA":
    $to_ryhma_tila = 8; $to_hlo_tila = 4;
    $to_selite = " ja kaikki siihen kuuluvat henkilt tauolle";
    break;
  case "ALOITTAA":
    $to_ryhma_tila = 11; $to_hlo_tila = 2;
    $to_selite =
      " aloittavaksi ja kaikki siihen kuuluvat henkilt tulossa oleviksi";
    break;
  case "LOPETTANUT":
    $to_ryhma_tila = 12; $to_hlo_tila = 5;
    $to_selite =
      " lopettaneeksi ja kaikki siihen kuuluvat henkilt poistuneiksi";
    break;
  case "KIERRATYS":
    $to_ryhma_tila = 12; $to_hlo_tila = 3; $to_ryhma = 1;
    $to_selite =
      " lopettaneeksi ja kaikki siihen kuuluvat henkilt vapaiksi";
    break;
  default:
    die("$file: tuntamaton combo $combo");
  }
  if (saa_tehda("$file:combo")) {
    $ret1 = ryhma_set_ryhma_tila_id_ok($herja1,$id,$to_ryhma_tila);
    $ret2 = hlo_set_hlo_tila_id_by_ryhma_id_ok($herja2,$id,$to_hlo_tila);
    if (($ret1 != 2) && ($ret2 != 2)) {
      $now = date('Y-m-d H:i:s');
      $sql =
	"UPDATE $table
         SET ryhma_tila_id=$to_ryhma_tila,
             ts='$now'
         WHERE id=$id";
      $result = my_mysql_query ($sql,true,true);
      $where = "WHERE ryhma_id=$id";
      $sql =
	"UPDATE hlo SET hlo_tila_id=$to_hlo_tila, ts='$now' $where";
      $result = my_mysql_query ($sql,true,true);
      add_hlo_ajat_sql($where);
      if ($to_ryhma != 0) {
	$sql =
	  "UPDATE hlo
           SET ryhma_id = $to_ryhma, ts = '$now'
           WHERE ryhma_id = $id";
	my_mysql_query($sql,true,true);
	add_hlo_ajat_sql("WHERE ryhma_id = $to_ryhma");
      }
      $msg = ota_kutsu($id) . $to_selite;
      taktinen_loki($msg);
      tehty($msg);
    }
    p_herja($ret1,$herja);
    p_herja($ret2,$herja);
  }
 }

if (($ryhma_tila_id != '') && saa_tehda("$file:ryhma_tila_id")) {
  $ret = ryhma_set_ryhma_tila_id_ok($herja,$id,$ryhma_tila_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql =
      "UPDATE $table SET ryhma_tila_id=$ryhma_tila_id, ts='$now' WHERE id=$id";
    $result = my_mysql_query ($sql);
    loki($sql);
    $msg = ota_kutsu($id) . " " . ota_ryhma_tila($ryhma_tila_id);
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
}

if (($paikka_id != '') && saa_tehda("$file:paikka_id")) {
  $ret = ryhma_set_paikka_id_ok($herja,$id,$paikka_id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    $sql = "UPDATE $table SET paikka_id=$paikka_id, ts='$now' WHERE id=$id";
    $result = my_mysql_query ($sql);
    loki($sql);
    $msg = ota_kutsu($id) . ", sijainti on nyt " . ota_paikka($paikka_id);
    taktinen_loki($msg);
    tehty($msg);
  }
  p_herja($ret,$herja);
}

if (($save != '') && saa_tehda("$file:save")) {
  $ret = ryhma_set_ok($herja,$id);
  if ($ret != 2) {
    $now = date('Y-m-d H:i:s');
    # jos koordinaatit ovat jo ennestn samat, ei lokia. samoin muut.
    $kdup = tab_col_id($table,"koordinaatit",$id);
    $tdup = tab_col_id($table,"tehtava",$id);
    $adup = tab_col_id($table,"toiminta_alue",$id);
    $kdup = tab_col_id($table,"toimintakanava",$id);
    $sql =
      "UPDATE $table
       SET koordinaatit='$koordinaatit',
           tehtava = '$tehtava',
           toiminta_alue = '$toiminta_alue',
           toimintakanava = '$toimintakanava',
           ts='$now'
       WHERE id=$id";
    $result = my_mysql_query ($sql);
    loki($sql);
    if ($kdup != $koordinaatit) {
      tehty("Koordinaatit asetettu: $koordinaatit");
      taktinen_loki(ota_kutsu($id)
		    . ": koordinaatit ovat nyt $koordinaatit");
    } # kdup
    if ($tdup != $tehtava) {
      tehty("Tehtv asetettu: $tehtava");
      taktinen_loki(ota_kutsu($id)
		    . ": tehtv: $tehtava");
    } # tdup
    if ($adup != $toiminta_alue) {
      tehty("Toiminta-alue asetettu: $toiminta_alue");
      taktinen_loki(ota_kutsu($id)
		    . ": toiminta-alue: $toiminta_alue");
    } # adup
    if ($kdup != $toimintakanava) {
      tehty("Toimintakanava asetettu: $toimintakanava\n");
      taktinen_loki(ota_kutsu($id)
		    . ": toimintakanava: $toimintakanava");
    } # kdup
  }
  p_herja($ret,$herja);
  if ($tap != '') {
    $ret = tap_add_ok($herja,s('alue'),
		      s('paivystys'),$id,$tap);
    $clear = "SAVE";
    if ($ret != 2) {
      $now = date('Y-m-d H:i:s');
      $sql =
	"INSERT INTO tap
         SET alue_id = " . s("alue") . ",
             paivystys_id = " . s("paivystys") . ",
             ryhma_id = $id,
             tap = '$tap',
             ts = '$now'";
      $result = my_mysql_query ($sql);
      loki("$sql id=" . last_insert_id());
      taktinen_loki(ota_kutsu($id)
		    . ": $tap");
      tehty("Kirjaus tehty: $tap");
    }
    p_herja($ret,$herja);
  }
}

echo "<form action=\"\" method=\"GET\">\n";

echo "<td><input type=\"hidden\" name=\"id\" size=8 maxlength=8";
echo " value=\"$id\">\n";

$sql =
  "SELECT kutsu,ryhma_tila_id,paikka_id,ryhma_tila,paikka,koordinaatit,verkko,
          $table.tehtava,$table.toiminta_alue,$table.toimintakanava
   FROM $table,ryhma_tila,paikka,verkko
   WHERE ryhma.id = $id
         AND ryhma_tila.id = ryhma_tila_id
         AND paikka.id = paikka_id
         AND verkko.id = verkko_id";
$result = my_mysql_query($sql);
$a = mysql_fetch_array($result);
$kutsu = $a['kutsu'];
$ryhma_tila_id = $a['ryhma_tila_id'];
$paikka_id = $a['paikka_id'];
$ryhma_tila = $a['ryhma_tila'];
$paikka = $a['paikka'];
$koordinaatit = $a['koordinaatit'];
$verkko = $a['verkko'];
$tehtava = $a['tehtava'];
$toiminta_alue = $a['toiminta_alue'];
$toimintakanava = $a['toimintakanava'];

echo "<table border=0>\n";
echo "<tr><td>Oletusverkko:<td>" . ota_oletus_verkko() . "\n";
echo "<tr><td>Kutsu:<td>$kutsu" . muotoile_verkko($verkko, $id) . "\n";
echo tr_vaalsin() . "<th><th>Nykyinen<th>Pivitysvaihtoehdot";
echo "<tr><td>Tila:<td" . bgcolor_vaalsin() . ">$ryhma_tila<td>";
ryhma_tilat ($id, $ryhma_tila_id);
echo "<tr><td>Sijainti:<td" . bgcolor_vaalsin() . ">$paikka<td>";
paikat ($id, $paikka_id);

echo "<tr><td><td>Koordinaatit";
echo "<td><input type=\"text\" name=\"koordinaatit\" size=32 maxlength=32\n";
echo " value=\"$koordinaatit\">\n";

echo "<tr><td><td>Tehtv";
echo "<td><input type=\"text\" name=\"tehtava\" size=64 maxlength=128\n";
echo " value=\"$tehtava\">\n";

echo "<tr><td><td>Toiminta-alue";
echo "<td><input type=\"text\" name=\"toiminta_alue\" size=64 maxlength=128\n";
echo " value=\"$toiminta_alue\">\n";

echo "<tr><td><td>Toimintakanava";
echo "<td><input type=\"text\" name=\"toimintakanava\" size=32 maxlength=32\n";
echo " value=\"$toimintakanava\">\n";

echo "<tr><td><td>Kirjaus";
echo "<td><input type=\"text\" name=\"tap\" size=64 maxlength=255\n";
echo " value=\"\">\n";

echo "<tr><td><td><input type=\"submit\" name=\"save\" value=\"TALLETA\">\n";

echo "</table>\n";

echo "<h2>Pivitysyhdistelmt (combot)</h2>";

echo "<table>
<tr><th>Yhdistelm<th>Selitys
<tr>
  <td><a href=\"$file?combo=VAPAANA&id=$id\">
    <font color=green>Vapaaksi<font></a>
  <td>Merkitse tm ryhm vapaaksi ja kaikki siihen kuuluvat henkilt paikalle.
<tr>
  <td><a href=\"$file?combo=KIINTEA&id=$id\">
    <font color=green>Kiinteksi<font></a>
  <td>Merkitse tm ryhm kiinteksi ja kaikki siihen kuuluvat henkilt
    paikalle.
<tr>
  <td><a href=\"$file?combo=TAUOLLA&id=$id\"><font color=blue>Tauolle<font></a>
  <td>Merkitse tm ryhm ja kaikki siihen kuuluvat henkilt tauolle.
<tr>
  <td><a href=\"$file?combo=ALOITTAA&id=$id\">
    <font color=blue>Aloittavaksi<font></a>
  <td>Merkitse tm ryhm aloittavaksi ja kaikki siihen kuuluvat henkilt
    tulossa oleviksi.
<tr>
  <td><a href=\"$file?combo=LOPETTANUT&id=$id\">
    <font color=blue>Lopettaneeksi<font></a>
  <td>Merkitse tm ryhm lopettaneeksi ja kaikki siihen kuuluvat henkilt
    poistuneiksi.
<tr>
  <td><a href=\"$file?combo=KIERRATYS&id=$id\">
    <font color=blue>Kierrtetyksi<font></a>
  <td>Merkitse tm ryhm lopettaneeksi ja vapauta sen henkilkunta odottamaan
    sijoittamista uuteen ryhmn.
</table>";

echo "<h2>Tulosteet</h2>";

echo "<p><a href=\"toimintaryhman-kortti.php?id=$id\">",
  "Toimintaryhmn kortti</a>\n";

echo "</form>\n";

loppu();

?>
</body> 
</html>
<!-- RCS $Id: ryhma-takt-1.php,v 1.38 2009/10/04 16:31:19 riku Exp $ -->
